@@ -1,5 +1,5 @@
 /*
- * Summary: string dictionnary
+ * Summary: string dictionary
  * Description: dictionary of reusable strings, just used to avoid allocation
  *         and freeing operations.
  *
@@ -11,16 +11,15 @@
 #ifndef __XML_DICT_H__
 #define __XML_DICT_H__
 
-#include <limits.h>
+#include <stddef.h>
 #include <libxml/xmlversion.h>
-#include <libxml/tree.h>
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 /*
- * The dictionnary.
+ * The dictionary.
  */
 typedef struct _xmlDict xmlDict;
 typedef xmlDict *xmlDictPtr;
@@ -28,6 +27,7 @@ typedef xmlDict *xmlDictPtr;
 /*
  * Initializer
  */
+XML_DEPRECATED
 XMLPUBFUN int XMLCALL  xmlInitializeDict(void);
 
 /*
@@ -48,7 +48,7 @@ XMLPUBFUN void XMLCALL
 			xmlDictFree	(xmlDictPtr dict);
 
 /*
- * Lookup of entry in the dictionnary.
+ * Lookup of entry in the dictionary.
  */
 XMLPUBFUN const xmlChar * XMLCALL
 			xmlDictLookup	(xmlDictPtr dict,
@@ -71,6 +71,7 @@ XMLPUBFUN int XMLCALL
 /*
  * Cleanup function
  */
+XML_DEPRECATED
 XMLPUBFUN void XMLCALL
                         xmlDictCleanup  (void);
 
